@@ -1,5 +1,7 @@
 import logging
 
+import matplotlib.pyplot as plt
+
 import fdsreader as fds
 
 
@@ -7,9 +9,9 @@ def main():
     ch = logging.StreamHandler()
     ch.setLevel(logging.DEBUG)
 
-    fds.settings.ENABLE_CACHING = False
+    # fds.settings.ENABLE_CACHING = False
 
-    sim = fds.Simulation("../../examples/slcf/fds_steckler")
+    sim = fds.Simulation("C:\\Users\\janv1\\PycharmProjects\\fdsreader\\examples\\slcf\\fds_steckler")
 
     mesh = sim.meshes[0]
     # Get the second slice
@@ -27,6 +29,10 @@ def main():
     # print(subslice.shape)
     # print(sslc_data)
 
+    plt.imshow(subslice.data[-1])
+    plt.colorbar()
+    plt.show()
+
 
 if __name__ == "__main__":
     main()
